#
# spec file for package ghc-hspec
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hspec
Name:           ghc-%{pkg_name}
Version:        2.7.0
Release:        lp151.1.3
Summary:        A Testing Framework for Haskell
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-core-devel
BuildRequires:  ghc-hspec-discover-devel
BuildRequires:  ghc-hspec-expectations-devel
BuildRequires:  ghc-rpm-macros

%description
Hspec is a testing framework for Haskell. Some of Hspec's distinctive features
are:

* a friendly DSL for defining tests

* integration with QuickCheck, SmallCheck, and HUnit

* parallel test execution

* automatic discovery of test files

The Hspec Manual is at <http://hspec.github.io/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown

%changelog
* Fri Jan 18 2019 psimons@suse.com
- Update hspec to version 2.7.0.
  [#]# Changes in 2.7.0
  - Add `--focused-only` (see #390)
  - Add `--fail-on-focused` (see #389)
* Tue Jan  1 2019 psimons@suse.com
- Update hspec to version 2.6.1.
  [#]# Changes in 2.6.1
  - Add `Test.Hspec.Runner.runSpec` (see #216)
* Sun Nov  4 2018 psimons@suse.com
- Update hspec to version 2.6.0.
  [#]# Changes in 2.6.0
  - Allow to focus individual spec items (see #319)
  - Do not calculate diff on `--no-diff` (see #332)
  - Remove deprecated module Test.Hspec.Core
  [#]# Changes in 2.5.9
  - Extract source locations from RecConError (see #375)
* Wed Oct 10 2018 psimons@suse.com
- Update hspec to version 2.5.8.
  [#]# Changes in 2.5.8
  - Add `modifyArgs` and `modifyMaxShrinks` to `Test.Hspec.QuickCheck` (see #380)
  [#]# Changes in 2.5.7
  - GHC 8.6.1 related changes
  [#]# Changes in 2.5.6
  - Compatibility with `QuickCheck-2.12`
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update hspec to version 2.5.5.
  [#]# Changes in 2.5.5
  - Use `module[line:column]` instead of `module:line:column` as default label
    for `describe`/`it` (fixes #366)
* Fri Jul 13 2018 psimons@suse.com
- Update hspec to version 2.5.4.
  - Show how to rerun individual spec items on test failures (see #205)
  - Treat character escapes like `\NUL` as single tokens on `--diff` (see #351)
  - Allow a `/` at the beginning and at the end of an absolute path that is
    passed to `--match` or `--skip`
  - Use module:line:column as default label for describe/it (see #250)
  - Warn if user is affected by https://ghc.haskell.org/trac/ghc/ticket/13285 (see #329)
  - Disable tests for Test.Hspec.Core.Timer (see #352)
* Mon May 14 2018 psimons@suse.com
- Update hspec to version 2.5.0.
  - Add support for `--diff` when `shouldBe` is uesd with
    `QuickCheck`-properties
  - Add source locations when `shouldBe` is uesd with `QuickCheck`-properties
  - Add `sequential` (see #311)
  - Colorize whitespaces with background color instead of foreground color with
    `--diff`
  - Deprecate `--out`
  - Removed deprecated module `Test.Hspec.HUnit`, use
    `Test.Hspec.Contrib.HUnit` instead
  - Run `Test.Hspec.Core.Formatters.exampleProgress` in `FormatM` instead of
    `IO`
  - Print QuickCheck labels on success (see #297)
  - Include column when formatting source locations
  - Extract source location from error / undefined (close #316)
  - Remove BestEffort source locations
  - Include duration for each spec item in new formatter API (see #315)
  - Add location information to `pending`
  - Make sure that progress output is always cleared (fixes #301)
  - Parse source locations from pattern match failures
  - compatibility with the upcoming version `4.11.0.0` of `base`
  - `hspec-discover`: Sort specs using natural sort order
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 2.4.4.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 2.4.3 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 2.4.2 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 2.4.1 with cabal2obs.
* Tue Nov  1 2016 psimons@suse.com
- Update to version 2.2.4 revision 1 with cabal2obs.
* Thu Oct  6 2016 psimons@suse.com
- Update to version 2.2.3 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.2.3 revision 0 with cabal2obs.
